pygeai.tests.snippets.usage\_limit package
==========================================

Submodules
----------

pygeai.tests.snippets.usage\_limit.delete\_usage\_limit module
--------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.usage_limit.delete_usage_limit
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.usage\_limit.get\_all\_usage\_limit\_from\_organization module
------------------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.usage_limit.get_all_usage_limit_from_organization
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.usage\_limit.get\_usage\_limit\_from\_organization module
-------------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.usage_limit.get_usage_limit_from_organization
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.usage\_limit.get\_usage\_limit\_from\_project module
--------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.usage_limit.get_usage_limit_from_project
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.usage\_limit.set\_usage\_limit\_organization module
-------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.usage_limit.set_usage_limit_organization
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.usage\_limit.set\_usage\_limit\_project module
--------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.usage_limit.set_usage_limit_project
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.usage\_limit.update\_usage\_limit\_organization module
----------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.usage_limit.update_usage_limit_organization
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.usage\_limit.update\_usage\_limit\_project module
-----------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.usage_limit.update_usage_limit_project
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.usage_limit
   :members:
   :show-inheritance:
   :undoc-members:
